@@ -215,8 +215,13 @@ class BaseSQLQueue(object):
         # The pool and lock cannot be pickled
         self.disable_pool()
         state = self.__dict__.copy()
-        del state['__sql_engine_pool']
-        del state['__sql_engine_pool_lock']
+
+        if state and '__sql_engine_pool' in state.keys():
+            del state['__sql_engine_pool']
+
+        if state and '__sql_engine_pool_lock' in state.keys():
+            del state['__sql_engine_pool_lock']
+
         return state
 
     def __setstate__(self, state):
